#
# spec file for package python3-h5py
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-h5py
Version:        2.5.0
Release:        4.1
Summary:        Python interface to the Hierarchical Data Format library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://www.h5py.org/
Source:         https://pypi.python.org/packages/source/h/h5py/h5py-%{version}.tar.gz
BuildRequires:  hdf5-devel
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pkgconfig
BuildRequires:  python3-six
Requires:       hdf5
Requires:       python3-Cython
Requires:       python3-numpy
Requires:       python3-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description

H5py provides a simple, robust read/write interface to HDF5 data from Python.
Existing Python and Numpy concepts are used for the interface; for example,
datasets on disk are represented by a proxy class that supports slicing, and
has dtype and shape attributes. HDF5 groups are presented using a dictionary
metaphor, indexed by name.

%prep
%setup -q -n h5py-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%clean
rm -rf %{buildroot}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ANN.rst README.rst lzf/LICENSE.txt lzf/README.txt examples licenses/*
%{python3_sitearch}/h5py/
%{python3_sitearch}/h5py-%{version}-py*.egg-info

%changelog
* Tue Jul 28 2015 toddrme2178@gmail.com
- Resolve hdf5 dependency ambiguity
* Fri Apr 10 2015 arun@gmx.de
- specfile:
  * changed from 2to3 to six
  * added build requirement for python3-pkgconfig
  * added Cython requirement for install
- update to version 2.5.0:
  * Experimental SWMR support
  * Group and AttributeManager classes now inherit from the appropriate ABCs
  * Fixed an issue with 64-bit float VLENS
  * Cython warning cleanups related to "const"
  * Entire code base ported to "six"; 2to3 removed from setup.py
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * remove python(abi) requirement
* Sat Jan 10 2015 arun@gmx.de
- specfile: update copyright year
- update to version 2.4.0:
  * This release incorporates a total re-write of the identifier
    management system in h5py. As part of this refactoring, the entire
    API is also now protected by threading locks.
  * Files are now automatically closed when all objects within them
    are unreachable. Previously, if File.close() was not explicitly
    closed, files would remain open and "leaks" were possible if the
    File object was lost.
  * The entire API is now believed to be thread-safe (feedback
    welcome!).
  * External links now work if the target file is already
    open. Previously this was not possible because of a mismatch in
    the file close strengths.
  * The options to setup.py have changed; a new top-level "configure"
    command handles options like --hdf5=/path/to/hdf5 and
  - -mpi. Setup.py now works correctly under Python 3 when these
    options are used.
  * Cython (0.17+) is now required when building from source.
  * The minimum NumPy version is now 1.6.1.
* Tue Jul 22 2014 toddrme2178@gmail.com
- Include files in license directory
* Fri Jul 18 2014 toddrme2178@gmail.com
- Include license in sources.
* Thu Jul 17 2014 toddrme2178@gmail.com
- Update download url
- spec file cleanups
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 2.3.1
  - Bugfix release which fixes a build issue when using the most
    recent version of HDF5 (1.8.13), and some issues with Travis-CI.
* Thu May  8 2014 toddrme2178@gmail.com
- Update to version 2.3.0
  - Support for arbitrary vlen data
  - Improved exception messages
  - Improved setuptools support
  - Multiple low-level additions
  - Improved support for MPI features
  - Readonly files can now be opened in default mode
  - Single-step build for HDF5 on Windows
* Mon Dec 16 2013 toddrme2178@gmail.com
- Update to version 2.2.1
  + Critical bugfixes
* Tue Dec 10 2013 p.drouand@gmail.com
- Update to version 2.2.0
  + This version of h5py introduces support for MPI/Parallel HDF5,
    using the mpi4py package.  Parallel HDF5 is the "native" method
    in HDF5 for sharing files and objects across multiple processes,
    in contrast to the "threading" package or "multiprocessing".
    There is a guide to using Parallel HDF5 at the h5py web site:
    http://www.h5py.org/docs/topics/mpi.html
  + Support for Python 3.3
  + Support for 16-bit "mini" floats
  + Access to the HDF5 scale-offset filter
  + Field names are now allowed when writing to a dataset
  + Region references now preserve the shape of their selections
  + File-resident "committed" types can be linked to datasets and attributes
  + Make object mtime tracking optional
  + A new "move" method on Group objects
  + Many new options for Group.copy
  + Access to HDF5's get_vfd_handle
  + Many bug fixes
- Remove depreciated %%{py_requires}
- Remove redundant %%clen section
- Remove useless %%post/postun sections
- Package ANN.rst, lzf/LICENSE.txt, lzf/README.txt and examples to
  documentation directory
* Tue Jul 23 2013 highwaystar.ru@gmail.com
- update to version 2.2.0b1
  * Support for Python 3.3
  * Support for Parallel HDF5
  * Mini float support (float16)
  * HDF5 scale/offset filter
  * Field indexing is now allowed when writing to a dataset (issue #42)
  * Region references preserve shape (issue #295)
  * Committed types can be linked to datasets and attributes
  * move method on Group objects
* Wed Apr 24 2013 highwaystar.ru@gmail.com
- update to version 2.1.3
  - no changelog
* Thu Nov 22 2012 toddrme2178@gmail.com
- Update to 2.1.0
  - No changelog
- Removed openSUSE 11.4 spec file workarounds
* Thu Apr 26 2012 highwaystar.ru@gmail.com
- initial build for python3
